@@ -5,7 +5,7 @@
  *
  * Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  *
- * $Id: tcp.h,v 1.1.1.1 2001/10/11 04:14:49 dugsong Exp $
+ * $Id: tcp.h,v 1.2 2001/10/30 19:23:26 dugsong Exp $
  */
 
 #ifndef DNET_TCP_H
@@ -26,18 +26,32 @@ struct tcp_hdr {
 			th_x2:4;	/* (unused) */
 #endif
 	u_char		th_flags;
+	u_short		th_win;		/* window */
+	u_short		th_sum;		/* checksum */
+	u_short		th_urp;		/* urgent pointer */
+};
+
+/* TCP flags */
 #define TH_FIN		0x01
 #define TH_SYN		0x02
 #define TH_RST		0x04
 #define TH_PUSH		0x08
 #define TH_ACK		0x10
 #define TH_URG		0x20
-	u_short		th_win;		/* window */
-	u_short		th_sum;		/* checksum */
-	u_short		th_urp;		/* urgent pointer */
-};
 
 #define TCP_PORT_MAX	65535
 #define TCP_WIN_MAX	65535		/* maximum (unscaled) window */
 
+#define tcp_fill(h, sport, dport, seq, ack, flags, win, urp) do {	\
+	struct tcp_hdr *tcp_fill_p = (struct tcp_hdr *)(h);		\
+	tcp_fill_p->th_sport = htons(sport);				\
+	tcp_fill_p->th_dport = htons(dport);				\
+	tcp_fill_p->th_seq = htonl(seq);				\
+	tcp_fill_p->th_ack = htonl(ack);				\
+	tcp_fill_p->th_x2 = 0; tcp_fill_p->th_off = 5;			\
+	tcp_fill_p->th_flags = flags;					\
+	tcp_fill_p->th_win = htons(win);				\
+	tcp_fill_p->th_urp = htons(urp);				\
+} while (0)
+
 #endif /* DNET_TCP_H */
