@@ -5,7 +5,7 @@
  *
  * Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  *
- * $Id: udp.h,v 1.1.1.1 2001/10/11 04:14:49 dugsong Exp $
+ * $Id: udp.h,v 1.2 2001/10/30 19:23:26 dugsong Exp $
  */
 
 #ifndef DNET_UDP_H
@@ -22,4 +22,11 @@ struct udp_hdr {
 
 #define UDP_PORT_MAX	65535
 
+#define udp_fill(h, sport, dport, ulen) do {			\
+	struct udp_hdr *udp_fill_p = (struct udp_hdr *)(h);	\
+	udp_fill_p->uh_sport = htons(sport);			\
+	udp_fill_p->uh_dport = htons(dport);			\
+	udp_fill_p->uh_ulen = htons(ulen);			\
+} while (0)
+
 #endif /* DNET_UDP_H */
